<template>
  <div>
    <div class="task-camera-box">
      <p class="title">
        <b>传感器</b>
        <span class="add-btn" @click="createSensor">
          <i class="iconfont">&#xe63f;</i>
        </span>
      </p>

      <div class="sub-task-rules-box">
        <div class="task-blank" v-show="groupRules.length == 0">
          <img src="/images/hashrate/摄像机空页面.png" alt="" />
          <div class="des">暂无传感器，请选择新增</div>
        </div>
        <div
          style="text-align: left"
          v-for="(rule, index) in groupRules"
          :key="index"
        >
          <div class="row">
            <!-- 选择区域 -->
            <el-checkbox v-model="rule.enable" style="margin-right: 24px">
              <span>
                {{ "开启" }}
              </span>
            </el-checkbox>

            <div class="wrapArea">
              <!-- 选择类型 -->
              <el-select
                v-model="rule.type"
                placeholder="选择类型"
                size="small"
              >
                <el-option
                  v-for="item in selectTypeOptions"
                  :key="item.value"
                  :label="item.label"
                  :value="item.value"
                >
                </el-option>
              </el-select>

              <!-- ip地址 -->
              <div style="width: 200px; margin: 5px 10px 5px 0">
                <ip-input
                  :ip="rule.ip"
                  @on-blur="rule.ip = arguments[0]"
                ></ip-input>
              </div>

              <el-input
                v-model="rule.port"
                placeholder="请输入端口"
                size="small"
              ></el-input>

              <el-input
                v-model="rule.username"
                placeholder="请输入用户名"
                size="small"
              ></el-input>

              <el-input
                v-model="rule.password"
                placeholder="请输入密码"
                size="small"
              ></el-input>

              <el-input
                v-model="rule.threshold"
                placeholder="请输入阈值"
                size="small"
              ></el-input>

              <!-- 新增、删除 按钮 -->
              <div class="iconfont del" @click="groupRules.splice(index, 1)">
                &#xe62a;
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>
<script>
import {
  deleteCameraRules,
  updateRuleDefence,
  updateAlarmLevel,
} from "@/api/camera";
import { findByType } from "@/api/taskMange";
import ipInput from "@/components/subComponents/IPInput";

export default {
  name: "TaskRuleEditor",
  components: {
    ipInput,
  },
  props: {
    Carmeras: {
      type: Object,
      default: () => {
        return {};
      },
    },
    sensors: {
      type: Array,
      default: () => {
        return [];
      },
    },
  },
  filters: {},
  computed: {},
  watch: {
    sensors: function (newVal, oldVal) {
      if (newVal !== oldVal) {
        this.groupRules = newVal;
      }
    },
  },
  data() {
    return {
      baseSensor: {
        enable: false,
        type: "",
        ip: "",
        id: "",
        port: "",
        username: "",
        password: "",
        threshold: "",
      },
      groupRules: [
        {
          enable: false,
          type: "",
          ip: "",
          id: "",
          port: "",
          username: "",
          password: "",
          threshold: "",
        },
      ],
      selectTypeOptions: [
        {
          value: "1",
          label: "温度",
        },
        {
          value: "2",
          label: "湿度",
        },
        {
          value: "3",
          label: "湿度",
        },
      ],
    };
  },
  methods: {
    createSensor() {
      this.groupRules.push(this.baseSensor);
    },
    getResult() {
      if (this.groupRules.length !== 0) {
        let list = this.groupRules.filter((item) => {
          return (
            item.selectType != "" ||
            item.cameraIp != "" ||
            item.cameraPort != "" ||
            item.cameraUserName != "" ||
            item.cameraPaw != "" ||
            item.cameraThro != ""
          );
        });
        this.groupRules = list;
        return list.map((i) => {
          i.port = Number(i.port);
          i.threshold = Number(i.threshold);
          return i;
        });
      }
    },
    // 查询字典
    async findByType() {
      let res = await findByType();
      if (res && res.success) {
        let list = res.data.sensorType.map((i) => {
          let obj = {};
          obj.label = i.name;
          obj.value = i.value;
          return obj;
        });
        this.selectTypeOptions = [...list];
      }
    },
  },
  mounted() {
    this.findByType();
  },
};
</script>

<style lang="scss" scoped>
.task-camera-box {
  width: 100%;
  padding-top: 5px;
  box-sizing: border-box;
  border-bottom: 1px solid #e9ebee;
  .sub-task-rules-box {
    width: 100%;
    min-height: 50px;
    padding-top: 7px;
    box-sizing: border-box;
    padding-bottom: 15px;
    .task-rules-button {
      text-align: right;
      margin: 15px;
    }

    .el-select {
      min-width: 130px;
      width: 12%;
    }
  }

  .el-button--text {
    text-decoration: unset;
  }

  .title {
    box-sizing: border-box;
    margin-bottom: 30px;
    padding-left: 10px;
    border-left: 4px solid #0065ff;
    font-size: 16px;
    font-weight: 700;

    .iconfont {
      margin-left: 20px;
      font-size: 16px;
      color: #0065ff;
      cursor: pointer;
    }
  }

  .row {
    display: flex;
    align-items: center;

    .wrapArea {
      display: flex;
      flex-wrap: wrap;
      align-items: center;
    }

    .el-select ::v-deep {
      margin: 5px 0;
      margin-right: 10px;
      width: 200px;
      height: 32px;

      input:focus {
        border-color: #0065ff;
      }

      .el-input.is-focus .el-input__inner {
        border-color: #0065ff;
      }

      input {
        border-color: #c0c5cc;
        border-radius: 0;
        height: 32px;

        &::-webkit-input-placeholder {
          color: #999;
        }
      }
    }

    .el-input ::v-deep {
      margin: 5px 0;
      margin-right: 10px;
      width: 160px;
      height: 32px;

      input {
        border-radius: 0;
        border-color: #c0c5cc;
        &::-webkit-input-placeholder {
          color: #999;
        }

        &:focus {
          border-color: #0065ff;
        }
      }
    }

    .del {
      margin: 5px 0;
      font-size: 16px;
      color: rgb(255, 75, 51);
      cursor: pointer;
    }

    ::v-deep .ip-input-container {
      border-color: #c0c5cc;
    }
  }

  .task-blank {
    text-align: center;
    font-size: 12px;
    font-weight: 700;
    color: #666;
    margin-top: 13px;

    img {
      margin-bottom: 10px;
      width: 250px;
    }
  }
  .nocamera-css {
    cursor: not-allowed;
    color: #3d68e1;
    margin-left: 10px;
    font-size: 14px;
  }
}
</style>